Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1099)

Unified Diff: content/browser/site_per_process_browsertest.cc

Issue 2863693003: Unify TouchAction classes (Closed)
Patch Set: add cstdlib Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/site_per_process_browsertest.cc
diff --git a/content/browser/site_per_process_browsertest.cc b/content/browser/site_per_process_browsertest.cc
index c992dd6e91cdce0ba601b67f5145c038e57938a2..9f40f6cbeb188cb821e9a74a1cf72411e6ea2a49 100644
--- a/content/browser/site_per_process_browsertest.cc
+++ b/content/browser/site_per_process_browsertest.cc
@@ -28,6 +28,7 @@
#include "base/threading/sequenced_task_runner_handle.h"
#include "base/threading/thread_task_runner_handle.h"
#include "build/build_config.h"
+#include "cc/input/touch_action.h"
#include "content/browser/frame_host/cross_process_frame_connector.h"
#include "content/browser/frame_host/frame_navigation_entry.h"
#include "content/browser/frame_host/frame_tree.h"
@@ -49,7 +50,6 @@
#include "content/common/child_process_messages.h"
#include "content/common/frame_messages.h"
#include "content/common/input/synthetic_tap_gesture_params.h"
-#include "content/common/input/touch_action.h"
#include "content/common/input_messages.h"
#include "content/common/renderer.mojom.h"
#include "content/common/view_messages.h"
@@ -5795,16 +5795,16 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessBrowserTest,
// There's no intrinsic reason the following values can't be equal, but they
// aren't at present, and if they become the same this test will need to be
// updated to accommodate.
- EXPECT_NE(TOUCH_ACTION_AUTO, TOUCH_ACTION_NONE);
+ EXPECT_NE(cc::kTouchActionAuto, cc::kTouchActionNone);
- // Verify the child's input router is initially set for TOUCH_ACTION_AUTO. The
- // TouchStart event will trigger TOUCH_ACTION_NONE being sent back to the
+ // Verify the child's input router is initially set for kTouchActionAuto. The
+ // TouchStart event will trigger kTouchActionNone being sent back to the
// browser.
RenderWidgetHostImpl* child_render_widget_host =
root->child_at(0)->current_frame_host()->GetRenderWidgetHost();
InputRouterImpl* child_input_router =
static_cast<InputRouterImpl*>(child_render_widget_host->input_router());
- EXPECT_EQ(TOUCH_ACTION_AUTO,
+ EXPECT_EQ(cc::kTouchActionAuto,
child_input_router->touch_action_filter_.allowed_touch_action());
// Simulate touch event to sub-frame.
@@ -5840,7 +5840,7 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessBrowserTest,
// Verify the presence of the touch handler in the child frame correctly
// propagates touch-action:none information back to the child's input router.
- EXPECT_EQ(TOUCH_ACTION_NONE,
+ EXPECT_EQ(cc::kTouchActionNone,
child_input_router->touch_action_filter_.allowed_touch_action());
}
@@ -5867,17 +5867,17 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessBrowserTest,
// There's no intrinsic reason the following values can't be equal, but they
// aren't at present, and if they become the same this test will need to be
// updated to accommodate.
- EXPECT_NE(TOUCH_ACTION_AUTO, TOUCH_ACTION_NONE);
+ EXPECT_NE(cc::kTouchActionAuto, cc::kTouchActionNone);
// Verify the main frame's input router is initially set for
// TOUCH_ACTION_AUTO. The
// TouchStart event will trigger TOUCH_ACTION_NONE being sent back to the
// browser.
RenderWidgetHostImpl* render_widget_host =
root->current_frame_host()->GetRenderWidgetHost();
InputRouterImpl* input_router =
static_cast<InputRouterImpl*>(render_widget_host->input_router());
- EXPECT_EQ(TOUCH_ACTION_AUTO,
+ EXPECT_EQ(cc::kTouchActionAuto,
input_router->touch_action_filter_.allowed_touch_action());
// Simulate touch event to sub-frame.
@@ -5913,7 +5913,7 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessBrowserTest,
// Verify the presence of the touch handler in the child frame correctly
// propagates touch-action:none information back to the child's input router.
- EXPECT_EQ(TOUCH_ACTION_NONE,
+ EXPECT_EQ(cc::kTouchActionNone,
input_router->touch_action_filter_.allowed_touch_action());
}
« no previous file with comments | « content/browser/renderer_host/input/touch_action_filter_unittest.cc ('k') | content/child/assert_matching_enums.cc » ('j') | no next file with comments »
@@ -5867,17 +5867,17 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessBrowserTest,
// Verify the main frame's input router is initially set for
- // TOUCH_ACTION_AUTO. The
- // TouchStart event will trigger TOUCH_ACTION_NONE being sent back to the
+ // kTouchActionAuto. The
+ // TouchStart event will trigger kTouchActionNone being sent back to the
// browser.
RenderWidgetHostImpl* render_widget_host =

Powered by Google App Engine
This is Rietveld 408576698